==> scanbot_sdk-2.4.1.tar.gz: lib/cropping_screen_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'cropping_screen_data.g.dart';

///Result class that return cropped page from crop rtu-ui component
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class CroppingResult extends Result {
  Page? page;

  CroppingResult(this.page);

  factory CroppingResult.fromJson(Map<String, dynamic> json) =>
      _$CroppingResultFromJson(json);

  Map<String, dynamic> toJson() => _$CroppingResultToJson(this);

  CroppingResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }
}

///Cropping rtu-ui component configuration class
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class CroppingScreenConfiguration {
  /// Background color of the main screen.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? backgroundColor;

  /// Background color of the bottom toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarBackgroundColor;

  /// Color of the titles of all buttons in the bottom toolbar (Rotate button).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarButtonsColor;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the Done button.
  String? doneButtonTitle;

  /// Default color of the cropping outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColor;

  /// Outline color of magnetically snapped edges.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColorMagnetic;

  /// Width of the cropping outline.
  int? polygonLineWidth;

  /// Title of the Rotate button.
  String? rotateButtonTitle;

  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// Color of the titles of all buttons in the top toolbar (Cancel and Done buttons).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Title in the top bar (iOS only).
  String? topBarTitle;

  /// Color of the title in the top bar (iOS only).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? titleColor;

  /// Title of the Detect button.
  String? detectButtonTitle;

  /// Title of the Reset button.
  String? resetButtonTitle;

  /// Controls whether the Rotate button is hidden or not.
  bool? rotateButtonHidden;

  /// Controls whether the Detect/Reset button is hidden or not.
  bool? detectResetButtonHidden;

  /// UI orientation lock mode: PORTRAIT, LANDSCAPE, etc.
  /// By default the UI is not locked.
  CameraOrientationMode? orientationLockMode;

  CroppingScreenConfiguration(
      {this.backgroundColor,
      this.bottomBarBackgroundColor,
      this.bottomBarButtonsColor,
      this.cancelButtonTitle,
      this.doneButtonTitle,
      this.polygonColor,
      this.polygonColorMagnetic,
      this.polygonLineWidth,
      this.rotateButtonTitle,
      this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.topBarTitle,
      this.titleColor,
      this.detectButtonTitle,
      this.resetButtonTitle,
      this.rotateButtonHidden,
      this.detectResetButtonHidden,
      this.orientationLockMode});

  factory CroppingScreenConfiguration.fromJson(Map<String, dynamic> json) =>
      _$CroppingScreenConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$CroppingScreenConfigurationToJson(this);
}

==> scanbot_sdk-2.9.0.tar.gz: lib/cropping_screen_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'cropping_screen_data.g.dart';

///Result class that return cropped page from crop rtu-ui component
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class CroppingResult extends Result {
  Page? page;

  CroppingResult(this.page);

  factory CroppingResult.fromJson(Map<String, dynamic> json) =>
      _$CroppingResultFromJson(json);

  Map<String, dynamic> toJson() => _$CroppingResultToJson(this);

  CroppingResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  CroppingResult.error() {
    operationResult = OperationResult.ERROR;
  }
}

///Cropping rtu-ui component configuration class
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class CroppingScreenConfiguration {
  /// Background color of the main screen.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? backgroundColor;

  /// Background color of the bottom toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarBackgroundColor;

  /// The color of the titles of all buttons in the bottom toolbar (Rotate button).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? bottomBarButtonsColor;

  /// Title of the cancel button.
  String? cancelButtonTitle;

  /// Title of the Done button.
  String? doneButtonTitle;

  /// Default color of the cropping outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColor;

  /// Outline color of magnetically snapped edges.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColorMagnetic;

  /// Width of the cropping outline.
  int? polygonLineWidth;

  /// Title of the Rotate button.
  String? rotateButtonTitle;

  /// Background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of the titles of all buttons in the top toolbar (Cancel and Done buttons).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// Title in the top bar (iOS only).
  String? topBarTitle;

  /// The color of the title in the top bar (iOS only).
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? titleColor;

  /// Title of the Detect button.
  String? detectButtonTitle;

  /// Title of the Reset button.
  String? resetButtonTitle;

  /// Controls whether the Rotate button is hidden or not.
  bool? rotateButtonHidden;

  /// Controls whether the Detect/Reset button is hidden or not.
  bool? detectResetButtonHidden;

  /// UI orientation lock mode: PORTRAIT, LANDSCAPE, etc.
  /// By default the UI is not locked.
  CameraOrientationMode? orientationLockMode;

  CroppingScreenConfiguration(
      {this.backgroundColor,
      this.bottomBarBackgroundColor,
      this.bottomBarButtonsColor,
      this.cancelButtonTitle,
      this.doneButtonTitle,
      this.polygonColor,
      this.polygonColorMagnetic,
      this.polygonLineWidth,
      this.rotateButtonTitle,
      this.topBarBackgroundColor,
      this.topBarButtonsColor,
      this.topBarTitle,
      this.titleColor,
      this.detectButtonTitle,
      this.resetButtonTitle,
      this.rotateButtonHidden,
      this.detectResetButtonHidden,
      this.orientationLockMode});

  factory CroppingScreenConfiguration.fromJson(Map<String, dynamic> json) =>
      _$CroppingScreenConfigurationFromJson(json);

  Map<String, dynamic> toJson() => _$CroppingScreenConfigurationToJson(this);
}
